@@ -29,6 +29,7 @@ class VerticaDialect(PGDialect):
         'TIME': sqltypes.TIME,
         'TIME': sqltypes.TIME(timezone=True),
         'TIMESTAMP': sqltypes.TIMESTAMP,
+        'TIMESTAMPTZ': sqltypes.TIMESTAMP(timezone=True),
         'TIMESTAMP WITH TIMEZONE': sqltypes.TIMESTAMP(timezone=True),
 
         # Not supported yet
@@ -155,42 +156,46 @@ class VerticaDialect(PGDialect):
         rs = connection.execute(' '.join(s))
         return [row[0] for row in rs]
 
-
     @reflection.cache
     def get_columns(self, connection, table_name, schema=None, **kw):
-        print('in get columns', table_name)
-        s = ("SELECT * FROM v_catalog.columns "
-             "WHERE table_name = '%s' ") % (table_name,)
+        schema_conditional = (
+            "" if schema is None else "AND table_schema = '{schema}'".format(schema=schema))
 
-        spk = ("SELECT column_name FROM v_catalog.primary_keys "
-               "WHERE table_name = '%s' "
-               "AND constraint_type = 'p'") % (table_name)
-
-        if schema is not None:
-            _pred = lambda p: ("%s AND table_schema = '%s'" % (p, schema))
-            s = _pred(s)
-            spk = _pred(spk)
-
-        pk_columns = [x[0] for x in connection.execute(spk)]
-        columns = []
-        for row in connection.execute(s):
-            name = row.column_name
-            dtype = row.data_type.upper()
-            if '(' in dtype:
-                dtype = dtype.split('(')[0]
-            coltype = self.ischema_names[dtype]
-            primary_key = name in pk_columns
-            default = row.column_default
-            nullable = row.is_nullable
-
-            columns.append({
-                'name': name,
-                'type': coltype,
-                'nullable': nullable,
-                'default': default,
-                'primary_key': primary_key
-            })
-        return columns
+        pk_column_select = """
+        SELECT column_name FROM v_catalog.primary_keys
+        WHERE table_name = '{table_name}'
+        AND constraint_type = 'p'
+        {schema_conditional}
+        """.format(table_name=table_name, schema_conditional=schema_conditional)
+        primary_key_columns = tuple(row[0] for row in connection.execute(pk_column_select))
+        column_select = """
+        SELECT
+          column_name,
+          data_type,
+          column_default,
+          is_nullable
+        FROM v_catalog.columns
+        where table_name = '{table_name}'
+        {schema_conditional}
+        UNION ALL
+        SELECT
+          column_name,
+          data_type,
+          '' as column_default,
+          true as is_nullable
+        FROM v_catalog.view_columns
+        where table_name = '{table_name}'
+        {schema_conditional}
+        """.format(table_name=table_name, schema_conditional=schema_conditional)
+        return [
+            {
+                'name': row.column_name,
+                'type': self.ischema_names[row.data_type.upper().split('(')[0]],
+                'nullable': row.is_nullable,
+                'default': row.column_default,
+                'primary_key': row.column_name in primary_key_columns
+            } for row in connection.execute(column_select)
+        ]
 
     @reflection.cache
     def get_unique_constraints(self, connection, table_name, schema=None, **kw):
@@ -220,6 +225,36 @@ class VerticaDialect(PGDialect):
 
         return result
 
+    @reflection.cache
+    def get_check_constraints(self, connection, table_name, schema=None, **kw):
+        query = """
+        SELECT
+            cons.constraint_name as name,
+            cons.predicate as src
+        FROM
+            v_catalog.table_constraints cons
+        WHERE
+            cons.table_id = (
+                SELECT
+                    i.table_id
+                FROM
+                    v_catalog.tables i]
+                WHERE
+                    i.table_name='{table_name}'
+                AND
+                    cons.constraint_type = 'c'
+                {schema_clause}
+            )
+        """.format(table_name=table_name, schema_clause=(
+            "" if schema is None else "AND i.table_schema ='{schema}'".format(schema)))
+
+        return [
+            {
+                'name': name,
+                'sqltext': src[1:-1]
+            } for name, src in connection.execute(query).fetchall()
+        ]
+
     # constraints are enforced on selects, but returning nothing for these
     # methods allows table introspection to work
 
